@@ -24,13 +24,11 @@ class TaskInfo;
 
 class PsCmd : public eckit::CmdResource {
 public:
-
     PsCmd();
 
-    virtual ~PsCmd();
-
-private: // methods
+    ~PsCmd() override;
 
+private:  // methods
     void display(std::ostream&, eckit::TaskInfo&, long, const std::string&) const;
     void display(JSON&, eckit::TaskInfo&, long, const std::string&) const;
 
@@ -39,14 +37,14 @@ private: // methods
 
     // From CmdResource
 
-    virtual void execute(std::istream&, std::ostream& out, eckit::CmdArg&);
-    virtual void help(std::ostream&) const;
+    void execute(std::istream&, std::ostream& out, eckit::CmdArg&) override;
+    void help(std::ostream&) const override;
 
-    virtual eckit::Arg usage(const std::string& cmd) const;
+    eckit::Arg usage(const std::string& cmd) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
