@@ -12,24 +12,23 @@
 #include "eckit/log/Log.h"
 #include "eckit/runtime/Monitorable.h"
 
-//----------------------------------------------------------------------------------------------------------------------
-
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-StatusCmd::StatusCmd() : CmdResource("status") {}
+StatusCmd::StatusCmd() :
+    CmdResource("status") {}
 
 StatusCmd::~StatusCmd() {}
 
-void StatusCmd::execute(std::istream&, std::ostream& out, CmdArg& arg) {
-    setformat(out, Log::monitorFormat);
+void StatusCmd::execute(std::istream&, std::ostream& out, CmdArg&) {
+    format(out, Log::monitorFormat);
     Monitorable::allStatuses(out);
 }
 
 void StatusCmd::help(std::ostream&) const {}
 
-Arg StatusCmd::usage(const std::string& cmd) const {
+Arg StatusCmd::usage(const std::string&) const {
     return Arg();
 }
 
