@@ -18,14 +18,10 @@ namespace eckit {
 class Stream;
 }
 
-
-namespace eckit {
-namespace linalg {
-
+namespace eckit::linalg {
 
 //-----------------------------------------------------------------------------
 
-
 /// Dense matrix in column major storage order
 class Matrix {
 public:  // types
@@ -130,6 +126,4 @@ Stream& operator<<(Stream&, const Matrix&);
 
 //-----------------------------------------------------------------------------
 
-
-}  // namespace linalg
-}  // namespace eckit
+}  // namespace eckit::linalg
