@@ -27,24 +27,23 @@ namespace eckit {
 class BigNum : private eckit::NonCopyable {
 
 public:
-
-	BigNum(long long v) : value_(v) {}
+    BigNum(long long v) :
+        value_(v) {}
 
 private:
+    void print(std::ostream&) const;
 
-	void print(std::ostream&) const;
+    static void print(std::ostream&, long long);
 
-	static void print(std::ostream&,long long);
-
-private: // members
-
-	long long value_;
-
-	friend std::ostream& operator<<(std::ostream& s,const BigNum& p)
-		{ p.print(s); return s; }
+private:  // members
+    long long value_;
 
+    friend std::ostream& operator<<(std::ostream& s, const BigNum& p) {
+        p.print(s);
+        return s;
+    }
 };
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
