@@ -18,8 +18,7 @@
 #include <iosfwd>
 #include <string>
 
-namespace eckit {
-namespace log {
+namespace eckit::log {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -36,7 +35,6 @@ public:
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace log
-} // namespace eckit
+}  // namespace eckit::log
 
 #endif
