@@ -23,24 +23,21 @@ namespace eckit {
 
 class OStreamTarget : public LogTarget {
 
-public: // methods
-
+public:  // methods
     OStreamTarget(std::ostream& out);
 
-    virtual ~OStreamTarget();
+    ~OStreamTarget() override;
 
-    virtual void write(const char* start, const char* end);
-    virtual void flush();
-    virtual void print(std::ostream& s) const;
+    void write(const char* start, const char* end) override;
+    void flush() override;
+    void print(std::ostream& s) const override;
 
 private:
-
     std::ostream& out_;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
