@@ -14,6 +14,7 @@
 #ifndef eckit_log_RotationTarget_h
 #define eckit_log_RotationTarget_h
 
+#include <string>
 
 #include "eckit/log/LogTarget.h"
 
@@ -23,21 +24,23 @@ namespace eckit {
 
 class RotationTarget : public LogTarget {
 
-public: // methods
+public:  // methods
+    RotationTarget(const std::string& name = std::string());
 
-    RotationTarget();
+    ~RotationTarget() override;
 
-    virtual ~RotationTarget();
-
-    virtual void write(const char* start, const char* end);
-    virtual void flush();
+    void write(const char* start, const char* end) override;
+    void flush() override;
 
 protected:
-    void print(std::ostream& s) const;
+    void print(std::ostream& s) const override;
+
+private:
+    std::string name_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
