@@ -11,8 +11,7 @@
 #ifndef eckit_mpi_Operation_h
 #define eckit_mpi_Operation_h
 
-namespace eckit {
-namespace mpi {
+namespace eckit::mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -39,7 +38,6 @@ Operation::Code minloc();
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace mpi
-}  // namespace eckit
+}  // namespace eckit::mpi
 
 #endif
