@@ -15,8 +15,7 @@
 
 #include "eckit/mpi/Status.h"
 
-namespace eckit {
-namespace mpi {
+namespace eckit::mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -28,11 +27,11 @@ class SerialStatus : public StatusContent {
 private:  // methods
     friend class Serial;
 
-    virtual int source() const { return source_; }
-    virtual int tag() const { return tag_; }
-    virtual int error() const { return error_; }
+    int source() const override { return source_; }
+    int tag() const override { return tag_; }
+    int error() const override { return error_; }
 
-    virtual void print(std::ostream&) const;
+    void print(std::ostream&) const override;
 
 private:  // members
     int source_;
@@ -44,7 +43,6 @@ private:  // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace mpi
-}  // namespace eckit
+}  // namespace eckit::mpi
 
 #endif
