@@ -12,16 +12,17 @@
 
 #include "eckit/exception/Exceptions.h"
 
-namespace eckit {
-namespace mpi {
+namespace eckit::mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Status::Status() : content_(new NullStatus()) {
+Status::Status() :
+    content_(new NullStatus()) {
     content_->attach();
 }
 
-Status::Status(StatusContent* p) : content_(p) {
+Status::Status(StatusContent* p) :
+    content_(p) {
     ASSERT(p);
     content_->attach();
 }
@@ -30,7 +31,8 @@ Status::~Status() {
     content_->detach();
 }
 
-Status::Status(const Status& s) : content_(s.content_) {
+Status::Status(const Status& s) :
+    content_(s.content_) {
     content_->attach();
 }
 
@@ -50,5 +52,4 @@ void NullStatus::print(std::ostream& os) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace mpi
-}  // namespace eckit
+}  // namespace eckit::mpi
