@@ -13,10 +13,10 @@
 #include "eckit/io/SockBuf.h"
 #include "eckit/net/TCPStream.h"
 
-namespace eckit {
-namespace net {
+namespace eckit::net {
 
-NetUser::NetUser(net::TCPSocket& protocol) : protocol_(protocol) {
+NetUser::NetUser(net::TCPSocket& protocol) :
+    protocol_(protocol) {
     Log::status() << "New connection from " << protocol_.remoteHost() << std::endl;
 }
 
@@ -33,6 +33,4 @@ void NetUser::run() {
     serve(stream, in, out);
 }
 
-
-}  // namespace net
-}  // namespace eckit
+}  // namespace eckit::net
