@@ -20,20 +20,22 @@
 namespace eckit {
 
 class Buffer;
+class Configuration;
+
+namespace net {
 
 
 class UDPClient : private NonCopyable {
 
 public:  // methods
-
+    explicit UDPClient(const Configuration& cfg);
     UDPClient(const std::string& hostname, int port);
 
     ~UDPClient();
 
-    void send(void* buf, long length);
-
-protected: // methods
+    void send(const void* buf, size_t length);
 
+protected:  // methods
     void print(std::ostream& s) const;
 
     friend std::ostream& operator<<(std::ostream& s, const UDPClient& socket) {
@@ -41,8 +43,7 @@ protected: // methods
         return s;
     }
 
-private: // members
-
+private:  // members
     std::string hostname_;
 
     int port_;
@@ -52,9 +53,12 @@ private: // members
     struct addrinfo* servinfo_;
     struct addrinfo* addr_;
 
+    void init();
 };
 
 
+}  // namespace net
 }  // namespace eckit
 
+
 #endif
