@@ -18,7 +18,8 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Monitorable::Monitorable() : ClassExtent<Monitorable>(this) {}
+Monitorable::Monitorable() :
+    ClassExtent<Monitorable>(this) {}
 
 Monitorable::~Monitorable() {}
 
