@@ -12,10 +12,7 @@
 #include "eckit/sql/SQLOutput.h"
 #include "eckit/utils/Translator.h"
 
-namespace eckit {
-namespace sql {
-namespace type {
-
+namespace eckit::sql::type {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -38,6 +35,4 @@ std::string SQLDouble::asString(const double* val) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace type
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql::type
