@@ -30,14 +30,14 @@
 #include "eckit/system/SystemInfo.h"
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/Mutex.h"
+#include "eckit/thread/ThreadSingleton.h"
 #include "eckit/utils/Translator.h"
 
 namespace eckit::system {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Library::Library(const std::string& name) :
-    name_(name), prefix_(name), debug_(false) {
+Library::Library(const std::string& name) : name_(name), prefix_(name), debug_(false) {
 
     LibraryManager::enregister(name, this);
 
@@ -109,25 +109,22 @@ std::string Library::libraryPath() const {
     return libraryPath_;
 }
 
+
 Channel& Library::debugChannel() const {
-    AutoLock<Mutex> lock(mutex_);
+    static ThreadSingleton<std::map<const Library*, std::unique_ptr<Channel>>> debugChannels;
 
-    if (debugChannel_) {
-        return *debugChannel_;
+    auto it = debugChannels.instance().find(this);
+    if (it != debugChannels.instance().end()) {
+        return *it->second;
     }
 
-    std::string s = prefix_ + "_DEBUG";
-
-    if (debug_) {
-        debugChannel_.reset(new Channel(new PrefixTarget(s)));
-    }
-    else {
-        debugChannel_.reset(new Channel());
-    }
-
-    return *debugChannel_;
+    return *debugChannels.instance()
+                .emplace(this, debug_ ? std::make_unique<Channel>(new PrefixTarget(prefix_ + "_DEBUG"))  //
+                                      : std::make_unique<Channel>())                                     //
+                .first->second.get();
 }
 
+
 const Configuration& Library::configuration() const {
     AutoLock<Mutex> lock(mutex_);
 
@@ -142,7 +139,8 @@ const Configuration& Library::configuration() const {
 
     Log::debug() << "Parsing Lib " << name_ << " config file " << cfgpath << std::endl;
 
-    eckit::Configuration* cfg = cfgpath.exists() ? new eckit::YAMLConfiguration(cfgpath) : new eckit::YAMLConfiguration(std::string(""));
+    eckit::Configuration* cfg
+        = cfgpath.exists() ? new eckit::YAMLConfiguration(cfgpath) : new eckit::YAMLConfiguration(std::string(""));
 
     Log::debug() << "Lib " << name_ << " configuration: " << *cfg << std::endl;
 
