@@ -41,7 +41,8 @@ public:
 
     // -- Contructors
 
-    Date() : julian_(0) {}
+    Date() :
+        julian_(0) {}
     Date(long);
     Date(long, long, long);
     Date(const std::string&);
@@ -51,7 +52,8 @@ public:
 
     // -- Copy
 
-    Date(const Date& other) : julian_(other.julian_) {}
+    Date(const Date& other) :
+        julian_(other.julian_) {}
 
     Date& operator=(const Date& other) {
         julian_ = other.julian_;
@@ -128,7 +130,8 @@ public:
     }
 
 protected:
-    Date(long julian, bool) : julian_(julian) {}
+    Date(long julian, bool) :
+        julian_(julian) {}
 
 private:
     // -- Members
