@@ -13,11 +13,11 @@
 #include "eckit/web/JavaUser.h"
 
 
-
 namespace eckit {
 
 
-JavaService::JavaService(int port) : net::NetService(port) {}
+JavaService::JavaService(int port) :
+    net::NetService(port) {}
 
 JavaService::~JavaService() {}
 
